==> igniteui-react-18.7.0-beta.2.tgz: package/esm5/lib/igr-checkbox.js <==
import { __assign, __extends } from "tslib";
import * as React from 'react';
import { IgrCheckboxBase } from "./igr-checkbox-base";
import { Checkbox } from "./Checkbox";
import { IgcCheckboxComponent, defineComponents } from "igniteui-webcomponents";
import { isValidProp, ensureBool } from "igniteui-react-core";
/**
 * A check box allowing single values to be selected/deselected.
*/
var IgrCheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrCheckbox, _super);
    function IgrCheckbox(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcCheckboxComponent);
        return _this;
    }
    IgrCheckbox.prototype.createImplementation = function () {
        return new Checkbox();
    };
    Object.defineProperty(IgrCheckbox.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCheckbox.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrCheckbox.prototype.render = function () {
        var _this = this;
        var nativePropsName = Object.keys(this.props).filter(function (prop) { return !isValidProp(_this, prop) && prop !== "originalRef"; });
        var nativeProps = {};
        nativePropsName.forEach(function (propName) {
            nativeProps[propName] = _this.props[propName];
        });
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-checkbox", __assign(__assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    };
    IgrCheckbox.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrCheckbox.prototype, "indeterminate", {
        /**
         * Draws the checkbox in indeterminate state.
        */
        get: function () {
            return this.i.y;
        },
        set: function (v) {
            this.i.y = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrCheckbox;
}(IgrCheckboxBase));
export { IgrCheckbox };

==> igniteui-react-18.7.5-beta.2.tgz: package/esm5/lib/igr-checkbox.js <==
import { __assign, __extends } from "tslib";
import * as React from 'react';
import { IgrCheckboxBase } from "./igr-checkbox-base";
import { Checkbox } from "./Checkbox";
import { IgcCheckboxComponent, defineComponents } from "igniteui-webcomponents";
import { isValidProp, ensureBool } from "igniteui-react-core";
/**
 * A check box allowing single values to be selected/deselected.
*/
var IgrCheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrCheckbox, _super);
    function IgrCheckbox(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcCheckboxComponent);
        return _this;
    }
    IgrCheckbox.prototype.createImplementation = function () {
        return new Checkbox();
    };
    Object.defineProperty(IgrCheckbox.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCheckbox.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        this.mounted = true;
        _super.prototype.componentDidMount.call(this);
    };
    IgrCheckbox.prototype.render = function () {
        var _this = this;
        var nativePropsName = Object.keys(this.props).filter(function (prop) { return !isValidProp(_this, prop) && prop !== "originalRef" && prop !== "className"; });
        var nativeProps = {};
        nativePropsName.forEach(function (propName) {
            nativeProps[propName] = _this.props[propName];
        });
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        this._portalManager.onRender(children);
        var style = {};
        if (this.props.style) {
            style = this.props.style;
        }
        var div = React.createElement("igc-checkbox", __assign(__assign({}, nativeProps), { ref: this._getMainRef, id: this.props.id, class: this.props.className, style: style, children: children }));
        return div;
    };
    IgrCheckbox.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrCheckbox.prototype, "indeterminate", {
        /**
         * Draws the checkbox in indeterminate state.
        */
        get: function () {
            return this.i.y;
        },
        set: function (v) {
            this.i.y = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrCheckbox;
}(IgrCheckboxBase));
export { IgrCheckbox };
